/* AttinyI2C

Sketch di esempio d'uso di un ATtiny85 
Il programma scrive da un ATtiny85
su una EEPROM esterna I2C e poi fa 
lampeggiare dei led sulla successiva 
lettura in base al dato letto

Sketch allegato alla guida
<<ATMEL AVR ATtiny
I microcontrollori “piccoli” di Atmel
Guida alla programmazione
valida per l'uso con le versioni 0022
dell'IDE di Arduino e del core Tiny>>
scritta da Leonardo Miliani

L'ultima versione della guida nonché del 
presente sketch è sempre scaricabile da:
www.leonardomiliani.com

Per favore diffondi lo sketch 
allegando la guida su citata

Se non hai ottenuto una copia della licenza,
puoi scaricarla dal sito www.fsf.org

Il presente codice è rilasciato sotto licenza 
GNU GPL v.3.0 o successive

*/

#include <TinyWireM.h> // I2C Master lib for ATTinys which use USI

#define EEPROM_ADDR 0x50 // 7 bit I2C address for EEPROM 24LC512
#define LED1_PIN 4 // ATtiny Pin 3
#define LED2_PIN 1 // ATtiny Pin 6


void setup(){
  pinMode(LED1_PIN,OUTPUT);
  pinMode(LED2_PIN,OUTPUT);
  TinyWireM.begin(); // initialize I2C lib
  digitalWrite(LED1_PIN, HIGH); // show it's alive
  digitalWrite(LED2_PIN, HIGH); // show it's alive
  delay(500);
  clear_eeprom();
  digitalWrite(LED2_PIN, LOW);
  digitalWrite(LED1_PIN, LOW);
  delay(1000);
}

void clear_eeprom() {
  unsigned int i;
  byte a[10]={1, 0, 0, 1, 1, 1, 0, 1, 0, 1};

  for (i=0; i<10; i++) {
    writeData(EEPROM_ADDR, i, a[i]);
    delay(5);
  }
}

void loop(){
  unsigned int i;
  byte temp, light;

  digitalWrite(LED1_PIN, HIGH);
  for (i=0; i<10; i++) {
    temp = readData(EEPROM_ADDR, i);
    if (temp == 0) {
      digitalWrite(LED2_PIN, LOW);
    } else {
      digitalWrite(LED2_PIN, HIGH);
    }
    delay(500);
    digitalWrite(LED2_PIN, LOW);
    delay(100);
  }
  digitalWrite(LED1_PIN, LOW);
  delay(500);
}

void writeData(int device, unsigned int add, byte data) {
  byte temp;
  // writes a byte of data 'data' to the chip at I2C address 'device', in memory location 'add'
  TinyWireM.beginTransmission(device);
  TinyWireM.send((byte)(add >> 8)); // left-part of pointer address
  TinyWireM.send((byte)(add & 0xFF)); // and the right
  TinyWireM.send(data);
  temp = TinyWireM.endTransmission();
  delay(5);
}

byte readData(int device, unsigned int add) {
  // reads a byte of data from memory location 'add' in chip at I2C address 'device'
  byte temp, result; // returned value
  TinyWireM.beginTransmission(device); // these three lines set the pointer position in the EEPROM
  TinyWireM.send((byte)(add >> 8)); // left-part of pointer address
  TinyWireM.send((byte)(add & 0xFF)); // and the right
  TinyWireM.endTransmission();
  TinyWireM.requestFrom(device, 1); // now get the byte of data...
  result = TinyWireM.receive();
  return result; // and return it as a result of the function readData
}
